# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.shape_base import ShapeBase

class SmartArt(ShapeBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'name': 'str',
        'width': 'float',
        'height': 'float',
        'alternative_text': 'str',
        'alternative_text_title': 'str',
        'hidden': 'bool',
        'x': 'float',
        'y': 'float',
        'z_order_position': 'int',
        'shapes': 'ResourceUriElement',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat',
        'type': 'str',
        'shape_type': 'str',
        'layout': 'str',
        'quick_style': 'str',
        'color_style': 'str',
        'nodes': 'list[SmartArtNode]',
        'is_reversed': 'bool'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'name': 'name',
        'width': 'width',
        'height': 'height',
        'alternative_text': 'alternativeText',
        'alternative_text_title': 'alternativeTextTitle',
        'hidden': 'hidden',
        'x': 'x',
        'y': 'y',
        'z_order_position': 'zOrderPosition',
        'shapes': 'shapes',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat',
        'type': 'type',
        'shape_type': 'shapeType',
        'layout': 'layout',
        'quick_style': 'quickStyle',
        'color_style': 'colorStyle',
        'nodes': 'nodes',
        'is_reversed': 'isReversed'
    }

    type_determiners = {
        'type': 'SmartArt',
        'shapeType': 'Diagram',
    }

    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='SmartArt', shape_type='Diagram', layout=None, quick_style=None, color_style=None, nodes=None, is_reversed=None):  # noqa: E501
        """SmartArt - a model defined in Swagger"""  # noqa: E501
        super(SmartArt, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type)

        self._layout = None
        self._quick_style = None
        self._color_style = None
        self._nodes = None
        self._is_reversed = None
        self.type: 'SmartArt'
        self.shape_type: 'Diagram'

        self.layout = layout
        self.quick_style = quick_style
        self.color_style = color_style
        if nodes is not None:
            self.nodes = nodes
        self.is_reversed = is_reversed

    @property
    def layout(self):
        """Gets the layout of this SmartArt.  # noqa: E501

        Layout type.  # noqa: E501

        :return: The layout of this SmartArt.  # noqa: E501
        :rtype: str
        """
        return self._layout

    @layout.setter
    def layout(self, layout):
        """Sets the layout of this SmartArt.

        Layout type.  # noqa: E501

        :param layout: The layout of this SmartArt.  # noqa: E501
        :type: str
        """
        if layout is not None:
            allowed_values = ["AccentProcess", "AccentedPicture", "AlternatingFlow", "AlternatingHexagons", "AlternatingPictureBlocks", "AlternatingPictureCircles", "ArrowRibbon", "AscendingPictureAccentProcess", "Balance", "BasicBendingProcess", "BasicBlockList", "BasicChevronProcess", "BasicCycle", "BasicMatrix", "BasicPie", "BasicProcess", "BasicPyramid", "BasicRadial", "BasicTarget", "BasicTimeline", "BasicVenn", "BendingPictureAccentList", "BendingPictureBlocks", "BendingPictureCaption", "BendingPictureCaptionList", "BendingPictureSemiTransparentText", "BlockCycle", "BubblePictureList", "CaptionedPictures", "ChevronList", "CircleAccentTimeline", "CircleArrowProcess", "CirclePictureHierarchy", "CircleRelationship", "CircularBendingProcess", "CircularPictureCallout", "ClosedChevronProcess", "ContinuousArrowProcess", "ContinuousBlockProcess", "ContinuousCycle", "ContinuousPictureList", "ConvergingArrows", "ConvergingRadial", "CounterbalanceArrows", "CycleMatrix", "DescendingBlockList", "DescendingProcess", "DetailedProcess", "DivergingArrows", "DivergingRadial", "Equation", "FramedTextPicture", "Funnel", "Gear", "GridMatrix", "GroupedList", "HalfCircleOrganizationChart", "HexagonCluster", "Hierarchy", "HierarchyList", "HorizontalBulletList", "HorizontalHierarchy", "HorizontalLabeledHierarchy", "HorizontalMultiLevelHierarchy", "HorizontalOrganizationChart", "HorizontalPictureList", "IncreasingArrowsProcess", "IncreasingCircleProcess", "InvertedPyramid", "LabeledHierarchy", "LinearVenn", "LinedList", "MultidirectionalCycle", "NameandTitleOrganizationChart", "NestedTarget", "NondirectionalCycle", "OpposingArrows", "OpposingIdeas", "OrganizationChart", "PhasedProcess", "PictureAccentBlocks", "PictureAccentList", "PictureAccentProcess", "PictureCaptionList", "PictureGrid", "PictureLineup", "PictureStrips", "PieProcess", "PlusandMinus", "ProcessArrows", "ProcessList", "PyramidList", "RadialCluster", "RadialCycle", "RadialList", "RadialVenn", "RandomToResultProcess", "RepeatingBendingProcess", "ReverseList", "SegmentedCycle", "SegmentedProcess", "SegmentedPyramid", "SnapshotPictureList", "SpiralPicture", "SquareAccentList", "StackedList", "StackedVenn", "StaggeredProcess", "StepDownProcess", "StepUpProcess", "SubStepProcess", "TableHierarchy", "TableList", "TargetList", "TextCycle", "TitlePictureLineup", "TitledMatrix", "TitledPictureAccentList", "TitledPictureBlocks", "TrapezoidList", "UpwardArrow", "VerticalAccentList", "VerticalArrowList", "VerticalBendingProcess", "VerticalBlockList", "VerticalBoxList", "VerticalBulletList", "VerticalChevronList", "VerticalCircleList", "VerticalCurvedList", "VerticalEquation", "VerticalPictureAccentList", "VerticalPictureList", "VerticalProcess", "Custom", "PictureOrganizationChart"]  # noqa: E501
            if layout.isdigit():
                int_layout = int(layout)
                if int_layout < 0 or int_layout >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `layout` ({0}), must be one of {1}"  # noqa: E501
                        .format(layout, allowed_values)
                    )
                self._layout = allowed_values[int_layout]
                return
            if layout not in allowed_values:
                raise ValueError(
                    "Invalid value for `layout` ({0}), must be one of {1}"  # noqa: E501
                    .format(layout, allowed_values)
                )
        self._layout = layout

    @property
    def quick_style(self):
        """Gets the quick_style of this SmartArt.  # noqa: E501

        Quick style.  # noqa: E501

        :return: The quick_style of this SmartArt.  # noqa: E501
        :rtype: str
        """
        return self._quick_style

    @quick_style.setter
    def quick_style(self, quick_style):
        """Sets the quick_style of this SmartArt.

        Quick style.  # noqa: E501

        :param quick_style: The quick_style of this SmartArt.  # noqa: E501
        :type: str
        """
        if quick_style is not None:
            allowed_values = ["SimpleFill", "WhiteOutline", "SubtleEffect", "ModerateEffect", "IntenceEffect", "Polished", "Inset", "Cartoon", "Powder", "BrickScene", "FlatScene", "MetallicScene", "SunsetScene", "BirdsEyeScene"]  # noqa: E501
            if quick_style.isdigit():
                int_quick_style = int(quick_style)
                if int_quick_style < 0 or int_quick_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `quick_style` ({0}), must be one of {1}"  # noqa: E501
                        .format(quick_style, allowed_values)
                    )
                self._quick_style = allowed_values[int_quick_style]
                return
            if quick_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `quick_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(quick_style, allowed_values)
                )
        self._quick_style = quick_style

    @property
    def color_style(self):
        """Gets the color_style of this SmartArt.  # noqa: E501

        Color style.  # noqa: E501

        :return: The color_style of this SmartArt.  # noqa: E501
        :rtype: str
        """
        return self._color_style

    @color_style.setter
    def color_style(self, color_style):
        """Sets the color_style of this SmartArt.

        Color style.  # noqa: E501

        :param color_style: The color_style of this SmartArt.  # noqa: E501
        :type: str
        """
        if color_style is not None:
            allowed_values = ["Dark1Outline", "Dark2Outline", "DarkFill", "ColorfulAccentColors", "ColorfulAccentColors2to3", "ColorfulAccentColors3to4", "ColorfulAccentColors4to5", "ColorfulAccentColors5to6", "ColoredOutlineAccent1", "ColoredFillAccent1", "GradientRangeAccent1", "GradientLoopAccent1", "TransparentGradientRangeAccent1", "ColoredOutlineAccent2", "ColoredFillAccent2", "GradientRangeAccent2", "GradientLoopAccent2", "TransparentGradientRangeAccent2", "ColoredOutlineAccent3", "ColoredFillAccent3", "GradientRangeAccent3", "GradientLoopAccent3", "TransparentGradientRangeAccent3", "ColoredOutlineAccent4", "ColoredFillAccent4", "GradientRangeAccent4", "GradientLoopAccent4", "TransparentGradientRangeAccent4", "ColoredOutlineAccent5", "ColoredFillAccent5", "GradientRangeAccent5", "GradientLoopAccent5", "TransparentGradientRangeAccent5", "ColoredOutlineAccent6", "ColoredFillAccent6", "GradientRangeAccent6", "GradientLoopAccent6", "TransparentGradientRangeAccent6"]  # noqa: E501
            if color_style.isdigit():
                int_color_style = int(color_style)
                if int_color_style < 0 or int_color_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `color_style` ({0}), must be one of {1}"  # noqa: E501
                        .format(color_style, allowed_values)
                    )
                self._color_style = allowed_values[int_color_style]
                return
            if color_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `color_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(color_style, allowed_values)
                )
        self._color_style = color_style

    @property
    def nodes(self):
        """Gets the nodes of this SmartArt.  # noqa: E501

        Collection of nodes in SmartArt object.               # noqa: E501

        :return: The nodes of this SmartArt.  # noqa: E501
        :rtype: list[SmartArtNode]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """Sets the nodes of this SmartArt.

        Collection of nodes in SmartArt object.               # noqa: E501

        :param nodes: The nodes of this SmartArt.  # noqa: E501
        :type: list[SmartArtNode]
        """
        self._nodes = nodes

    @property
    def is_reversed(self):
        """Gets the is_reversed of this SmartArt.  # noqa: E501

        The state of the SmartArt diagram with regard to (left-to-right) LTR or (right-to-left) RTL, if the diagram supports reversal.  # noqa: E501

        :return: The is_reversed of this SmartArt.  # noqa: E501
        :rtype: bool
        """
        return self._is_reversed

    @is_reversed.setter
    def is_reversed(self, is_reversed):
        """Sets the is_reversed of this SmartArt.

        The state of the SmartArt diagram with regard to (left-to-right) LTR or (right-to-left) RTL, if the diagram supports reversal.  # noqa: E501

        :param is_reversed: The is_reversed of this SmartArt.  # noqa: E501
        :type: bool
        """
        self._is_reversed = is_reversed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmartArt):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.shape_base import ShapeBase

class Table(ShapeBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'name': 'str',
        'width': 'float',
        'height': 'float',
        'alternative_text': 'str',
        'alternative_text_title': 'str',
        'hidden': 'bool',
        'x': 'float',
        'y': 'float',
        'z_order_position': 'int',
        'shapes': 'ResourceUriElement',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat',
        'type': 'str',
        'shape_type': 'str',
        'style': 'str',
        'rows': 'list[TableRow]',
        'columns': 'list[TableColumn]',
        'first_col': 'bool',
        'first_row': 'bool',
        'horizontal_banding': 'bool',
        'last_col': 'bool',
        'last_row': 'bool',
        'right_to_left': 'bool',
        'vertical_banding': 'bool'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'name': 'name',
        'width': 'width',
        'height': 'height',
        'alternative_text': 'alternativeText',
        'alternative_text_title': 'alternativeTextTitle',
        'hidden': 'hidden',
        'x': 'x',
        'y': 'y',
        'z_order_position': 'zOrderPosition',
        'shapes': 'shapes',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat',
        'type': 'type',
        'shape_type': 'shapeType',
        'style': 'style',
        'rows': 'rows',
        'columns': 'columns',
        'first_col': 'firstCol',
        'first_row': 'firstRow',
        'horizontal_banding': 'horizontalBanding',
        'last_col': 'lastCol',
        'last_row': 'lastRow',
        'right_to_left': 'rightToLeft',
        'vertical_banding': 'verticalBanding'
    }

    type_determiners = {
        'type': 'Table',
        'shapeType': 'Table',
    }

    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='Table', shape_type='Table', style=None, rows=None, columns=None, first_col=None, first_row=None, horizontal_banding=None, last_col=None, last_row=None, right_to_left=None, vertical_banding=None):  # noqa: E501
        """Table - a model defined in Swagger"""  # noqa: E501
        super(Table, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type)

        self._style = None
        self._rows = None
        self._columns = None
        self._first_col = None
        self._first_row = None
        self._horizontal_banding = None
        self._last_col = None
        self._last_row = None
        self._right_to_left = None
        self._vertical_banding = None
        self.type: 'Table'
        self.shape_type: 'Table'

        if style is not None:
            self.style = style
        if rows is not None:
            self.rows = rows
        if columns is not None:
            self.columns = columns
        if first_col is not None:
            self.first_col = first_col
        if first_row is not None:
            self.first_row = first_row
        if horizontal_banding is not None:
            self.horizontal_banding = horizontal_banding
        if last_col is not None:
            self.last_col = last_col
        if last_row is not None:
            self.last_row = last_row
        if right_to_left is not None:
            self.right_to_left = right_to_left
        if vertical_banding is not None:
            self.vertical_banding = vertical_banding

    @property
    def style(self):
        """Gets the style of this Table.  # noqa: E501

        Builtin table style.  # noqa: E501

        :return: The style of this Table.  # noqa: E501
        :rtype: str
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this Table.

        Builtin table style.  # noqa: E501

        :param style: The style of this Table.  # noqa: E501
        :type: str
        """
        if style is not None:
            allowed_values = ["None", "MediumStyle2Accent1", "MediumStyle2", "NoStyleNoGrid", "ThemedStyle1Accent1", "ThemedStyle1Accent2", "ThemedStyle1Accent3", "ThemedStyle1Accent4", "ThemedStyle1Accent5", "ThemedStyle1Accent6", "NoStyleTableGrid", "ThemedStyle2Accent1", "ThemedStyle2Accent2", "ThemedStyle2Accent3", "ThemedStyle2Accent4", "ThemedStyle2Accent5", "ThemedStyle2Accent6", "LightStyle1", "LightStyle1Accent1", "LightStyle1Accent2", "LightStyle1Accent3", "LightStyle1Accent4", "LightStyle2Accent5", "LightStyle1Accent6", "LightStyle2", "LightStyle2Accent1", "LightStyle2Accent2", "LightStyle2Accent3", "MediumStyle2Accent3", "MediumStyle2Accent4", "MediumStyle2Accent5", "LightStyle2Accent6", "LightStyle2Accent4", "LightStyle3", "LightStyle3Accent1", "MediumStyle2Accent2", "LightStyle3Accent2", "LightStyle3Accent3", "LightStyle3Accent4", "LightStyle3Accent5", "LightStyle3Accent6", "MediumStyle1", "MediumStyle1Accent1", "MediumStyle1Accent2", "MediumStyle1Accent3", "MediumStyle1Accent4", "MediumStyle1Accent5", "MediumStyle1Accent6", "MediumStyle2Accent6", "MediumStyle3", "MediumStyle3Accent1", "MediumStyle3Accent2", "MediumStyle3Accent3", "MediumStyle3Accent4", "MediumStyle3Accent5", "MediumStyle3Accent6", "MediumStyle4", "MediumStyle4Accent1", "MediumStyle4Accent2", "MediumStyle4Accent3", "MediumStyle4Accent4", "MediumStyle4Accent5", "MediumStyle4Accent6", "DarkStyle1", "DarkStyle1Accent1", "DarkStyle1Accent2", "DarkStyle1Accent3", "DarkStyle1Accent4", "DarkStyle1Accent5", "DarkStyle1Accent6", "DarkStyle2", "DarkStyle2Accent1Accent2", "DarkStyle2Accent3Accent4", "DarkStyle2Accent5Accent6", "LightStyle1Accent5", "Custom"]  # noqa: E501
            if style.isdigit():
                int_style = int(style)
                if int_style < 0 or int_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                        .format(style, allowed_values)
                    )
                self._style = allowed_values[int_style]
                return
            if style not in allowed_values:
                raise ValueError(
                    "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                    .format(style, allowed_values)
                )
        self._style = style

    @property
    def rows(self):
        """Gets the rows of this Table.  # noqa: E501

        Rows.  # noqa: E501

        :return: The rows of this Table.  # noqa: E501
        :rtype: list[TableRow]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """Sets the rows of this Table.

        Rows.  # noqa: E501

        :param rows: The rows of this Table.  # noqa: E501
        :type: list[TableRow]
        """
        self._rows = rows

    @property
    def columns(self):
        """Gets the columns of this Table.  # noqa: E501

        Columns.  # noqa: E501

        :return: The columns of this Table.  # noqa: E501
        :rtype: list[TableColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this Table.

        Columns.  # noqa: E501

        :param columns: The columns of this Table.  # noqa: E501
        :type: list[TableColumn]
        """
        self._columns = columns

    @property
    def first_col(self):
        """Gets the first_col of this Table.  # noqa: E501

        Determines whether the first column of a table has to be drawn with a special formatting.  # noqa: E501

        :return: The first_col of this Table.  # noqa: E501
        :rtype: bool
        """
        return self._first_col

    @first_col.setter
    def first_col(self, first_col):
        """Sets the first_col of this Table.

        Determines whether the first column of a table has to be drawn with a special formatting.  # noqa: E501

        :param first_col: The first_col of this Table.  # noqa: E501
        :type: bool
        """
        self._first_col = first_col

    @property
    def first_row(self):
        """Gets the first_row of this Table.  # noqa: E501

        Determines whether the first row of a table has to be drawn with a special formatting.  # noqa: E501

        :return: The first_row of this Table.  # noqa: E501
        :rtype: bool
        """
        return self._first_row

    @first_row.setter
    def first_row(self, first_row):
        """Sets the first_row of this Table.

        Determines whether the first row of a table has to be drawn with a special formatting.  # noqa: E501

        :param first_row: The first_row of this Table.  # noqa: E501
        :type: bool
        """
        self._first_row = first_row

    @property
    def horizontal_banding(self):
        """Gets the horizontal_banding of this Table.  # noqa: E501

        Determines whether the even rows has to be drawn with a different formatting.  # noqa: E501

        :return: The horizontal_banding of this Table.  # noqa: E501
        :rtype: bool
        """
        return self._horizontal_banding

    @horizontal_banding.setter
    def horizontal_banding(self, horizontal_banding):
        """Sets the horizontal_banding of this Table.

        Determines whether the even rows has to be drawn with a different formatting.  # noqa: E501

        :param horizontal_banding: The horizontal_banding of this Table.  # noqa: E501
        :type: bool
        """
        self._horizontal_banding = horizontal_banding

    @property
    def last_col(self):
        """Gets the last_col of this Table.  # noqa: E501

        Determines whether the last column of a table has to be drawn with a special formatting.  # noqa: E501

        :return: The last_col of this Table.  # noqa: E501
        :rtype: bool
        """
        return self._last_col

    @last_col.setter
    def last_col(self, last_col):
        """Sets the last_col of this Table.

        Determines whether the last column of a table has to be drawn with a special formatting.  # noqa: E501

        :param last_col: The last_col of this Table.  # noqa: E501
        :type: bool
        """
        self._last_col = last_col

    @property
    def last_row(self):
        """Gets the last_row of this Table.  # noqa: E501

        Determines whether the last row of a table has to be drawn with a special formatting.  # noqa: E501

        :return: The last_row of this Table.  # noqa: E501
        :rtype: bool
        """
        return self._last_row

    @last_row.setter
    def last_row(self, last_row):
        """Sets the last_row of this Table.

        Determines whether the last row of a table has to be drawn with a special formatting.  # noqa: E501

        :param last_row: The last_row of this Table.  # noqa: E501
        :type: bool
        """
        self._last_row = last_row

    @property
    def right_to_left(self):
        """Gets the right_to_left of this Table.  # noqa: E501

        Determines whether the table has right to left reading order.  # noqa: E501

        :return: The right_to_left of this Table.  # noqa: E501
        :rtype: bool
        """
        return self._right_to_left

    @right_to_left.setter
    def right_to_left(self, right_to_left):
        """Sets the right_to_left of this Table.

        Determines whether the table has right to left reading order.  # noqa: E501

        :param right_to_left: The right_to_left of this Table.  # noqa: E501
        :type: bool
        """
        self._right_to_left = right_to_left

    @property
    def vertical_banding(self):
        """Gets the vertical_banding of this Table.  # noqa: E501

        Determines whether the even columns has to be drawn with a different formatting.  # noqa: E501

        :return: The vertical_banding of this Table.  # noqa: E501
        :rtype: bool
        """
        return self._vertical_banding

    @vertical_banding.setter
    def vertical_banding(self, vertical_banding):
        """Sets the vertical_banding of this Table.

        Determines whether the even columns has to be drawn with a different formatting.  # noqa: E501

        :param vertical_banding: The vertical_banding of this Table.  # noqa: E501
        :type: bool
        """
        self._vertical_banding = vertical_banding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Table):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.fill_format import FillFormat

class PatternFill(FillFormat):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'back_color': 'str',
        'fore_color': 'str',
        'style': 'str'
    }

    attribute_map = {
        'type': 'type',
        'back_color': 'backColor',
        'fore_color': 'foreColor',
        'style': 'style'
    }

    type_determiners = {
        'type': 'Pattern',
    }

    def __init__(self, type='Pattern', back_color=None, fore_color=None, style=None):  # noqa: E501
        """PatternFill - a model defined in Swagger"""  # noqa: E501
        super(PatternFill, self).__init__(type)

        self._back_color = None
        self._fore_color = None
        self._style = None
        self.type: 'Pattern'

        if back_color is not None:
            self.back_color = back_color
        if fore_color is not None:
            self.fore_color = fore_color
        self.style = style

    @property
    def back_color(self):
        """Gets the back_color of this PatternFill.  # noqa: E501

        Gets or sets the back color of the pattern fill.  # noqa: E501

        :return: The back_color of this PatternFill.  # noqa: E501
        :rtype: str
        """
        return self._back_color

    @back_color.setter
    def back_color(self, back_color):
        """Sets the back_color of this PatternFill.

        Gets or sets the back color of the pattern fill.  # noqa: E501

        :param back_color: The back_color of this PatternFill.  # noqa: E501
        :type: str
        """
        self._back_color = back_color

    @property
    def fore_color(self):
        """Gets the fore_color of this PatternFill.  # noqa: E501

        Gets or sets the fore color of the pattern fill.  # noqa: E501

        :return: The fore_color of this PatternFill.  # noqa: E501
        :rtype: str
        """
        return self._fore_color

    @fore_color.setter
    def fore_color(self, fore_color):
        """Sets the fore_color of this PatternFill.

        Gets or sets the fore color of the pattern fill.  # noqa: E501

        :param fore_color: The fore_color of this PatternFill.  # noqa: E501
        :type: str
        """
        self._fore_color = fore_color

    @property
    def style(self):
        """Gets the style of this PatternFill.  # noqa: E501

        Gets or sets the style of pattern fill.  # noqa: E501

        :return: The style of this PatternFill.  # noqa: E501
        :rtype: str
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this PatternFill.

        Gets or sets the style of pattern fill.  # noqa: E501

        :param style: The style of this PatternFill.  # noqa: E501
        :type: str
        """
        if style is not None:
            allowed_values = ["Unknown", "Percent05", "Percent10", "Percent20", "Percent25", "Percent30", "Percent40", "Percent50", "Percent60", "Percent70", "Percent75", "Percent80", "Percent90", "DarkHorizontal", "DarkVertical", "DarkDownwardDiagonal", "DarkUpwardDiagonal", "SmallCheckerBoard", "Trellis", "LightHorizontal", "LightVertical", "LightDownwardDiagonal", "LightUpwardDiagonal", "SmallGrid", "DottedDiamond", "WideDownwardDiagonal", "WideUpwardDiagonal", "DashedUpwardDiagonal", "DashedDownwardDiagonal", "NarrowVertical", "NarrowHorizontal", "DashedVertical", "DashedHorizontal", "LargeConfetti", "LargeGrid", "HorizontalBrick", "LargeCheckerBoard", "SmallConfetti", "Zigzag", "SolidDiamond", "DiagonalBrick", "OutlinedDiamond", "Plaid", "Sphere", "Weave", "DottedGrid", "Divot", "Shingle", "Wave", "Horizontal", "Vertical", "Cross", "DownwardDiagonal", "UpwardDiagonal", "DiagonalCross", "NotDefined"]  # noqa: E501
            if style.isdigit():
                int_style = int(style)
                if int_style < 0 or int_style >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                        .format(style, allowed_values)
                    )
                self._style = allowed_values[int_style]
                return
            if style not in allowed_values:
                raise ValueError(
                    "Invalid value for `style` ({0}), must be one of {1}"  # noqa: E501
                    .format(style, allowed_values)
                )
        self._style = style

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatternFill):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class ReflectionEffect(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'direction': 'float',
        'fade_direction': 'float',
        'distance': 'float',
        'blur_radius': 'float',
        'scale_horizontal': 'float',
        'scale_vertical': 'float',
        'skew_horizontal': 'float',
        'skew_vertical': 'float',
        'start_pos_alpha': 'float',
        'end_pos_alpha': 'float',
        'start_reflection_opacity': 'float',
        'end_reflection_opacity': 'float',
        'rectangle_align': 'str',
        'rotate_shadow_with_shape': 'bool'
    }

    attribute_map = {
        'direction': 'direction',
        'fade_direction': 'fadeDirection',
        'distance': 'distance',
        'blur_radius': 'blurRadius',
        'scale_horizontal': 'scaleHorizontal',
        'scale_vertical': 'scaleVertical',
        'skew_horizontal': 'skewHorizontal',
        'skew_vertical': 'skewVertical',
        'start_pos_alpha': 'startPosAlpha',
        'end_pos_alpha': 'endPosAlpha',
        'start_reflection_opacity': 'startReflectionOpacity',
        'end_reflection_opacity': 'endReflectionOpacity',
        'rectangle_align': 'rectangleAlign',
        'rotate_shadow_with_shape': 'rotateShadowWithShape'
    }

    type_determiners = {
    }

    def __init__(self, direction=None, fade_direction=None, distance=None, blur_radius=None, scale_horizontal=None, scale_vertical=None, skew_horizontal=None, skew_vertical=None, start_pos_alpha=None, end_pos_alpha=None, start_reflection_opacity=None, end_reflection_opacity=None, rectangle_align=None, rotate_shadow_with_shape=None):  # noqa: E501
        """ReflectionEffect - a model defined in Swagger"""  # noqa: E501

        self._direction = None
        self._fade_direction = None
        self._distance = None
        self._blur_radius = None
        self._scale_horizontal = None
        self._scale_vertical = None
        self._skew_horizontal = None
        self._skew_vertical = None
        self._start_pos_alpha = None
        self._end_pos_alpha = None
        self._start_reflection_opacity = None
        self._end_reflection_opacity = None
        self._rectangle_align = None
        self._rotate_shadow_with_shape = None

        self.direction = direction
        self.fade_direction = fade_direction
        self.distance = distance
        self.blur_radius = blur_radius
        self.scale_horizontal = scale_horizontal
        self.scale_vertical = scale_vertical
        self.skew_horizontal = skew_horizontal
        self.skew_vertical = skew_vertical
        self.start_pos_alpha = start_pos_alpha
        self.end_pos_alpha = end_pos_alpha
        self.start_reflection_opacity = start_reflection_opacity
        self.end_reflection_opacity = end_reflection_opacity
        self.rectangle_align = rectangle_align
        self.rotate_shadow_with_shape = rotate_shadow_with_shape

    @property
    def direction(self):
        """Gets the direction of this ReflectionEffect.  # noqa: E501

        direction  # noqa: E501

        :return: The direction of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this ReflectionEffect.

        direction  # noqa: E501

        :param direction: The direction of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._direction = direction

    @property
    def fade_direction(self):
        """Gets the fade_direction of this ReflectionEffect.  # noqa: E501

        fade direction  # noqa: E501

        :return: The fade_direction of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._fade_direction

    @fade_direction.setter
    def fade_direction(self, fade_direction):
        """Sets the fade_direction of this ReflectionEffect.

        fade direction  # noqa: E501

        :param fade_direction: The fade_direction of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._fade_direction = fade_direction

    @property
    def distance(self):
        """Gets the distance of this ReflectionEffect.  # noqa: E501

        distance  # noqa: E501

        :return: The distance of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this ReflectionEffect.

        distance  # noqa: E501

        :param distance: The distance of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._distance = distance

    @property
    def blur_radius(self):
        """Gets the blur_radius of this ReflectionEffect.  # noqa: E501

        blur radius  # noqa: E501

        :return: The blur_radius of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._blur_radius

    @blur_radius.setter
    def blur_radius(self, blur_radius):
        """Sets the blur_radius of this ReflectionEffect.

        blur radius  # noqa: E501

        :param blur_radius: The blur_radius of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._blur_radius = blur_radius

    @property
    def scale_horizontal(self):
        """Gets the scale_horizontal of this ReflectionEffect.  # noqa: E501

        scale horizontal  # noqa: E501

        :return: The scale_horizontal of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._scale_horizontal

    @scale_horizontal.setter
    def scale_horizontal(self, scale_horizontal):
        """Sets the scale_horizontal of this ReflectionEffect.

        scale horizontal  # noqa: E501

        :param scale_horizontal: The scale_horizontal of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._scale_horizontal = scale_horizontal

    @property
    def scale_vertical(self):
        """Gets the scale_vertical of this ReflectionEffect.  # noqa: E501

        scale vertical  # noqa: E501

        :return: The scale_vertical of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._scale_vertical

    @scale_vertical.setter
    def scale_vertical(self, scale_vertical):
        """Sets the scale_vertical of this ReflectionEffect.

        scale vertical  # noqa: E501

        :param scale_vertical: The scale_vertical of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._scale_vertical = scale_vertical

    @property
    def skew_horizontal(self):
        """Gets the skew_horizontal of this ReflectionEffect.  # noqa: E501

        skew horizontal  # noqa: E501

        :return: The skew_horizontal of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._skew_horizontal

    @skew_horizontal.setter
    def skew_horizontal(self, skew_horizontal):
        """Sets the skew_horizontal of this ReflectionEffect.

        skew horizontal  # noqa: E501

        :param skew_horizontal: The skew_horizontal of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._skew_horizontal = skew_horizontal

    @property
    def skew_vertical(self):
        """Gets the skew_vertical of this ReflectionEffect.  # noqa: E501

        skew vertical  # noqa: E501

        :return: The skew_vertical of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._skew_vertical

    @skew_vertical.setter
    def skew_vertical(self, skew_vertical):
        """Sets the skew_vertical of this ReflectionEffect.

        skew vertical  # noqa: E501

        :param skew_vertical: The skew_vertical of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._skew_vertical = skew_vertical

    @property
    def start_pos_alpha(self):
        """Gets the start_pos_alpha of this ReflectionEffect.  # noqa: E501

        start pos alpha  # noqa: E501

        :return: The start_pos_alpha of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._start_pos_alpha

    @start_pos_alpha.setter
    def start_pos_alpha(self, start_pos_alpha):
        """Sets the start_pos_alpha of this ReflectionEffect.

        start pos alpha  # noqa: E501

        :param start_pos_alpha: The start_pos_alpha of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._start_pos_alpha = start_pos_alpha

    @property
    def end_pos_alpha(self):
        """Gets the end_pos_alpha of this ReflectionEffect.  # noqa: E501

        end pos alpha  # noqa: E501

        :return: The end_pos_alpha of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._end_pos_alpha

    @end_pos_alpha.setter
    def end_pos_alpha(self, end_pos_alpha):
        """Sets the end_pos_alpha of this ReflectionEffect.

        end pos alpha  # noqa: E501

        :param end_pos_alpha: The end_pos_alpha of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._end_pos_alpha = end_pos_alpha

    @property
    def start_reflection_opacity(self):
        """Gets the start_reflection_opacity of this ReflectionEffect.  # noqa: E501

        start reflection opacity  # noqa: E501

        :return: The start_reflection_opacity of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._start_reflection_opacity

    @start_reflection_opacity.setter
    def start_reflection_opacity(self, start_reflection_opacity):
        """Sets the start_reflection_opacity of this ReflectionEffect.

        start reflection opacity  # noqa: E501

        :param start_reflection_opacity: The start_reflection_opacity of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._start_reflection_opacity = start_reflection_opacity

    @property
    def end_reflection_opacity(self):
        """Gets the end_reflection_opacity of this ReflectionEffect.  # noqa: E501

        end reflection opacity  # noqa: E501

        :return: The end_reflection_opacity of this ReflectionEffect.  # noqa: E501
        :rtype: float
        """
        return self._end_reflection_opacity

    @end_reflection_opacity.setter
    def end_reflection_opacity(self, end_reflection_opacity):
        """Sets the end_reflection_opacity of this ReflectionEffect.

        end reflection opacity  # noqa: E501

        :param end_reflection_opacity: The end_reflection_opacity of this ReflectionEffect.  # noqa: E501
        :type: float
        """
        self._end_reflection_opacity = end_reflection_opacity

    @property
    def rectangle_align(self):
        """Gets the rectangle_align of this ReflectionEffect.  # noqa: E501

        rectangle alignment  # noqa: E501

        :return: The rectangle_align of this ReflectionEffect.  # noqa: E501
        :rtype: str
        """
        return self._rectangle_align

    @rectangle_align.setter
    def rectangle_align(self, rectangle_align):
        """Sets the rectangle_align of this ReflectionEffect.

        rectangle alignment  # noqa: E501

        :param rectangle_align: The rectangle_align of this ReflectionEffect.  # noqa: E501
        :type: str
        """
        if rectangle_align is not None:
            allowed_values = ["TopLeft", "Top", "TopRight", "Left", "Center", "Right", "BottomLeft", "Bottom", "BottomRight", "NotDefined"]  # noqa: E501
            if rectangle_align.isdigit():
                int_rectangle_align = int(rectangle_align)
                if int_rectangle_align < 0 or int_rectangle_align >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `rectangle_align` ({0}), must be one of {1}"  # noqa: E501
                        .format(rectangle_align, allowed_values)
                    )
                self._rectangle_align = allowed_values[int_rectangle_align]
                return
            if rectangle_align not in allowed_values:
                raise ValueError(
                    "Invalid value for `rectangle_align` ({0}), must be one of {1}"  # noqa: E501
                    .format(rectangle_align, allowed_values)
                )
        self._rectangle_align = rectangle_align

    @property
    def rotate_shadow_with_shape(self):
        """Gets the rotate_shadow_with_shape of this ReflectionEffect.  # noqa: E501

        true if the reflection should rotate with the shape when the shape is rotated  # noqa: E501

        :return: The rotate_shadow_with_shape of this ReflectionEffect.  # noqa: E501
        :rtype: bool
        """
        return self._rotate_shadow_with_shape

    @rotate_shadow_with_shape.setter
    def rotate_shadow_with_shape(self, rotate_shadow_with_shape):
        """Sets the rotate_shadow_with_shape of this ReflectionEffect.

        true if the reflection should rotate with the shape when the shape is rotated  # noqa: E501

        :param rotate_shadow_with_shape: The rotate_shadow_with_shape of this ReflectionEffect.  # noqa: E501
        :type: bool
        """
        self._rotate_shadow_with_shape = rotate_shadow_with_shape

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReflectionEffect):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

from __future__ import absolute_import

class CopyFileRequest(object):

    def __init__(self, src_path, dest_path, src_storage_name = None, dest_storage_name = None, version_id = None):
        self.src_path = src_path
        self.dest_path = dest_path
        self.src_storage_name = src_storage_name
        self.dest_storage_name = dest_storage_name
        self.version_id = version_id

class CopyFolderRequest(object):

    def __init__(self, src_path, dest_path, src_storage_name = None, dest_storage_name = None):
        self.src_path = src_path
        self.dest_path = dest_path
        self.src_storage_name = src_storage_name
        self.dest_storage_name = dest_storage_name

class CreateFolderRequest(object):

    def __init__(self, path = None, storage_name = None):
        self.path = path
        self.storage_name = storage_name

class DeleteFileRequest(object):

    def __init__(self, path = None, storage_name = None, version_id = None):
        self.path = path
        self.storage_name = storage_name
        self.version_id = version_id

class DeleteFolderRequest(object):

    def __init__(self, path = None, storage_name = None, recursive = None):
        self.path = path
        self.storage_name = storage_name
        self.recursive = recursive

class DeleteNotesSlideRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteNotesSlideParagraphRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteNotesSlideParagraphsRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, paragraphs = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.paragraphs = paragraphs
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteNotesSlidePortionRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, portion_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.portion_index = portion_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteNotesSlidePortionsRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, portions = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.portions = portions
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteNotesSlideShapeRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteNotesSlideShapesRequest(object):

    def __init__(self, name, slide_index, path = None, shapes = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.path = path
        self.shapes = shapes
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteParagraphRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteParagraphsRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, paragraphs = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.paragraphs = paragraphs
        self.password = password
        self.folder = folder
        self.storage = storage

class DeletePortionRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, portion_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.portion_index = portion_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class DeletePortionsRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, portions = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.portions = portions
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideAnimationRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideAnimationEffectRequest(object):

    def __init__(self, name, slide_index, effect_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.effect_index = effect_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideAnimationInteractiveSequenceRequest(object):

    def __init__(self, name, slide_index, sequence_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.sequence_index = sequence_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideAnimationInteractiveSequenceEffectRequest(object):

    def __init__(self, name, slide_index, sequence_index, effect_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.sequence_index = sequence_index
        self.effect_index = effect_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideAnimationInteractiveSequencesRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideAnimationMainSequenceRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideByIndexRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideShapeRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlideShapesRequest(object):

    def __init__(self, name, slide_index, path = None, shapes = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.path = path
        self.shapes = shapes
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlidesCleanSlidesListRequest(object):

    def __init__(self, name, slides = None, password = None, folder = None, storage = None):
        self.name = name
        self.slides = slides
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlidesDocumentPropertiesRequest(object):

    def __init__(self, name, password = None, folder = None, storage = None):
        self.name = name
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlidesDocumentPropertyRequest(object):

    def __init__(self, name, property_name, password = None, folder = None, storage = None):
        self.name = name
        self.property_name = property_name
        self.password = password
        self.folder = folder
        self.storage = storage

class DeleteSlidesSlideBackgroundRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class DownloadFileRequest(object):

    def __init__(self, path = None, storage_name = None, version_id = None):
        self.path = path
        self.storage_name = storage_name
        self.version_id = version_id

class GetDiscUsageRequest(object):

    def __init__(self, storage_name = None):
        self.storage_name = storage_name

class GetFileVersionsRequest(object):

    def __init__(self, path = None, storage_name = None):
        self.path = path
        self.storage_name = storage_name

class GetFilesListRequest(object):

    def __init__(self, path = None, storage_name = None):
        self.path = path
        self.storage_name = storage_name

class GetLayoutSlideRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetLayoutSlidesListRequest(object):

    def __init__(self, name, password = None, folder = None, storage = None):
        self.name = name
        self.password = password
        self.folder = folder
        self.storage = storage

class GetMasterSlideRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetMasterSlidesListRequest(object):

    def __init__(self, name, password = None, folder = None, storage = None):
        self.name = name
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideShapeRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideShapeParagraphRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideShapeParagraphsRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideShapePortionRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, portion_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.portion_index = portion_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideShapePortionsRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideShapesRequest(object):

    def __init__(self, name, slide_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetNotesSlideWithFormatRequest(object):

    def __init__(self, name, slide_index, format, width = None, height = None, password = None, folder = None, storage = None, fonts_folder = None):
        self.name = name
        self.slide_index = slide_index
        self.format = format
        self.width = width
        self.height = height
        self.password = password
        self.folder = folder
        self.storage = storage
        self.fonts_folder = fonts_folder

class GetParagraphPortionRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, portion_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.portion_index = portion_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetParagraphPortionsRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlideAnimationRequest(object):

    def __init__(self, name, slide_index, shape_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlideShapeRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlideShapeParagraphRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlideShapeParagraphsRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlideShapesRequest(object):

    def __init__(self, name, slide_index, path = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.path = path
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesDocumentRequest(object):

    def __init__(self, name, password = None, storage = None, folder = None):
        self.name = name
        self.password = password
        self.storage = storage
        self.folder = folder

class GetSlidesDocumentPropertiesRequest(object):

    def __init__(self, name, password = None, folder = None, storage = None):
        self.name = name
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesDocumentPropertyRequest(object):

    def __init__(self, name, property_name, password = None, folder = None, storage = None):
        self.name = name
        self.property_name = property_name
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesImageWithDefaultFormatRequest(object):

    def __init__(self, name, index, password = None, folder = None, storage = None):
        self.name = name
        self.index = index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesImageWithFormatRequest(object):

    def __init__(self, name, index, format, password = None, folder = None, storage = None):
        self.name = name
        self.index = index
        self.format = format
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesImagesRequest(object):

    def __init__(self, name, password = None, folder = None, storage = None):
        self.name = name
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesPlaceholderRequest(object):

    def __init__(self, name, slide_index, placeholder_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.placeholder_index = placeholder_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesPlaceholdersRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesPresentationTextItemsRequest(object):

    def __init__(self, name, with_empty = None, password = None, folder = None, storage = None):
        self.name = name
        self.with_empty = with_empty
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesSlideRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesSlideBackgroundRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesSlideCommentsRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesSlideImagesRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesSlideTextItemsRequest(object):

    def __init__(self, name, slide_index, with_empty = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.with_empty = with_empty
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesSlidesListRequest(object):

    def __init__(self, name, password = None, folder = None, storage = None):
        self.name = name
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesThemeRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesThemeColorSchemeRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesThemeFontSchemeRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesThemeFormatSchemeRequest(object):

    def __init__(self, name, slide_index, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.password = password
        self.folder = folder
        self.storage = storage

class GetSlidesViewPropertiesRequest(object):

    def __init__(self, name, password = None, folder = None, storage = None):
        self.name = name
        self.password = password
        self.folder = folder
        self.storage = storage

class MoveFileRequest(object):

    def __init__(self, src_path, dest_path, src_storage_name = None, dest_storage_name = None, version_id = None):
        self.src_path = src_path
        self.dest_path = dest_path
        self.src_storage_name = src_storage_name
        self.dest_storage_name = dest_storage_name
        self.version_id = version_id

class MoveFolderRequest(object):

    def __init__(self, src_path, dest_path, src_storage_name = None, dest_storage_name = None):
        self.src_path = src_path
        self.dest_path = dest_path
        self.src_storage_name = src_storage_name
        self.dest_storage_name = dest_storage_name

class ObjectExistsRequest(object):

    def __init__(self, path = None, storage_name = None, version_id = None):
        self.path = path
        self.storage_name = storage_name
        self.version_id = version_id

class PostAddNewParagraphRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, dto = None, password = None, folder = None, storage = None, position = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage
        self.position = position

class PostAddNewPortionRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, dto = None, password = None, folder = None, storage = None, position = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage
        self.position = position

class PostAddNewShapeRequest(object):

    def __init__(self, name, slide_index, path = None, dto = None, password = None, folder = None, storage = None, shape_to_clone = None, position = None):
        self.name = name
        self.slide_index = slide_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage
        self.shape_to_clone = shape_to_clone
        self.position = position

class PostAddNotesSlideRequest(object):

    def __init__(self, name, slide_index, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PostCopyLayoutSlideFromSourcePresentationRequest(object):

    def __init__(self, name, clone_from, clone_from_position, clone_from_password = None, clone_from_storage = None, password = None, folder = None, storage = None):
        self.name = name
        self.clone_from = clone_from
        self.clone_from_position = clone_from_position
        self.clone_from_password = clone_from_password
        self.clone_from_storage = clone_from_storage
        self.password = password
        self.folder = folder
        self.storage = storage

class PostCopyMasterSlideFromSourcePresentationRequest(object):

    def __init__(self, name, clone_from, clone_from_position, clone_from_password = None, clone_from_storage = None, apply_to_all = None, password = None, folder = None, storage = None):
        self.name = name
        self.clone_from = clone_from
        self.clone_from_position = clone_from_position
        self.clone_from_password = clone_from_password
        self.clone_from_storage = clone_from_storage
        self.apply_to_all = apply_to_all
        self.password = password
        self.folder = folder
        self.storage = storage

class PostNotesSlideAddNewParagraphRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, dto = None, password = None, folder = None, storage = None, position = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage
        self.position = position

class PostNotesSlideAddNewPortionRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, dto = None, password = None, folder = None, storage = None, position = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage
        self.position = position

class PostNotesSlideAddNewShapeRequest(object):

    def __init__(self, name, slide_index, path = None, dto = None, password = None, folder = None, storage = None, shape_to_clone = None, position = None):
        self.name = name
        self.slide_index = slide_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage
        self.shape_to_clone = shape_to_clone
        self.position = position

class PostNotesSlideShapeSaveAsRequest(object):

    def __init__(self, name, slide_index, shape_index, format, path = None, options = None, password = None, folder = None, storage = None, scale_x = None, scale_y = None, bounds = None, fonts_folder = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.format = format
        self.path = path
        self.options = options
        self.password = password
        self.folder = folder
        self.storage = storage
        self.scale_x = scale_x
        self.scale_y = scale_y
        self.bounds = bounds
        self.fonts_folder = fonts_folder

class PostPresentationMergeRequest(object):

    def __init__(self, name, request = None, password = None, storage = None, folder = None):
        self.name = name
        self.request = request
        self.password = password
        self.storage = storage
        self.folder = folder

class PostShapeSaveAsRequest(object):

    def __init__(self, name, slide_index, shape_index, format, path = None, options = None, password = None, folder = None, storage = None, scale_x = None, scale_y = None, bounds = None, fonts_folder = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.format = format
        self.path = path
        self.options = options
        self.password = password
        self.folder = folder
        self.storage = storage
        self.scale_x = scale_x
        self.scale_y = scale_y
        self.bounds = bounds
        self.fonts_folder = fonts_folder

class PostSlideAnimationEffectRequest(object):

    def __init__(self, name, slide_index, effect = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.effect = effect
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlideAnimationInteractiveSequenceRequest(object):

    def __init__(self, name, slide_index, sequence = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.sequence = sequence
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlideAnimationInteractiveSequenceEffectRequest(object):

    def __init__(self, name, slide_index, sequence_index, effect = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.sequence_index = sequence_index
        self.effect = effect
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlideSaveAsRequest(object):

    def __init__(self, name, slide_index, format, options = None, width = None, height = None, password = None, folder = None, storage = None, fonts_folder = None):
        self.name = name
        self.slide_index = slide_index
        self.format = format
        self.options = options
        self.width = width
        self.height = height
        self.password = password
        self.folder = folder
        self.storage = storage
        self.fonts_folder = fonts_folder

class PostSlidesAddRequest(object):

    def __init__(self, name, position = None, password = None, folder = None, storage = None, layout_alias = None):
        self.name = name
        self.position = position
        self.password = password
        self.folder = folder
        self.storage = storage
        self.layout_alias = layout_alias

class PostSlidesConvertRequest(object):

    def __init__(self, format, document = None, password = None, fonts_folder = None):
        self.format = format
        self.document = document
        self.password = password
        self.fonts_folder = fonts_folder

class PostSlidesCopyRequest(object):

    def __init__(self, name, slide_to_copy, position = None, source = None, source_password = None, source_storage = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_to_copy = slide_to_copy
        self.position = position
        self.source = source
        self.source_password = source_password
        self.source_storage = source_storage
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlidesDocumentRequest(object):

    def __init__(self, name, data = None, input_password = None, password = None, storage = None, folder = None):
        self.name = name
        self.data = data
        self.input_password = input_password
        self.password = password
        self.storage = storage
        self.folder = folder

class PostSlidesDocumentFromHtmlRequest(object):

    def __init__(self, name, html = None, password = None, storage = None, folder = None):
        self.name = name
        self.html = html
        self.password = password
        self.storage = storage
        self.folder = folder

class PostSlidesDocumentFromSourceRequest(object):

    def __init__(self, name, source_path = None, source_password = None, source_storage = None, password = None, storage = None, folder = None):
        self.name = name
        self.source_path = source_path
        self.source_password = source_password
        self.source_storage = source_storage
        self.password = password
        self.storage = storage
        self.folder = folder

class PostSlidesDocumentFromTemplateRequest(object):

    def __init__(self, name, template_path, data = None, template_password = None, template_storage = None, is_image_data_embedded = None, password = None, storage = None, folder = None):
        self.name = name
        self.template_path = template_path
        self.data = data
        self.template_password = template_password
        self.template_storage = template_storage
        self.is_image_data_embedded = is_image_data_embedded
        self.password = password
        self.storage = storage
        self.folder = folder

class PostSlidesPipelineRequest(object):

    def __init__(self, pipeline = None, files = None):
        self.pipeline = pipeline
        self.files = files

class PostSlidesPresentationReplaceTextRequest(object):

    def __init__(self, name, old_value, new_value, ignore_case = None, password = None, folder = None, storage = None):
        self.name = name
        self.old_value = old_value
        self.new_value = new_value
        self.ignore_case = ignore_case
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlidesReorderRequest(object):

    def __init__(self, name, slide_index, new_position, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.new_position = new_position
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlidesReorderManyRequest(object):

    def __init__(self, name, old_positions = None, new_positions = None, password = None, folder = None, storage = None):
        self.name = name
        self.old_positions = old_positions
        self.new_positions = new_positions
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlidesSaveAsRequest(object):

    def __init__(self, name, format, options = None, password = None, storage = None, folder = None, fonts_folder = None):
        self.name = name
        self.format = format
        self.options = options
        self.password = password
        self.storage = storage
        self.folder = folder
        self.fonts_folder = fonts_folder

class PostSlidesSetDocumentPropertiesRequest(object):

    def __init__(self, name, properties = None, password = None, folder = None, storage = None):
        self.name = name
        self.properties = properties
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlidesSlideReplaceTextRequest(object):

    def __init__(self, name, slide_index, old_value, new_value, ignore_case = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.old_value = old_value
        self.new_value = new_value
        self.ignore_case = ignore_case
        self.password = password
        self.folder = folder
        self.storage = storage

class PostSlidesSplitRequest(object):

    def __init__(self, name, options = None, format = None, width = None, height = None, to = None, _from = None, dest_folder = None, password = None, storage = None, folder = None, fonts_folder = None):
        self.name = name
        self.options = options
        self.format = format
        self.width = width
        self.height = height
        self.to = to
        self._from = _from
        self.dest_folder = dest_folder
        self.password = password
        self.storage = storage
        self.folder = folder
        self.fonts_folder = fonts_folder

class PutLayoutSlideRequest(object):

    def __init__(self, name, slide_index, slide_dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.slide_dto = slide_dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutNotesSlideShapeSaveAsRequest(object):

    def __init__(self, name, slide_index, shape_index, format, out_path, path = None, options = None, password = None, folder = None, storage = None, scale_x = None, scale_y = None, bounds = None, fonts_folder = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.format = format
        self.out_path = out_path
        self.path = path
        self.options = options
        self.password = password
        self.folder = folder
        self.storage = storage
        self.scale_x = scale_x
        self.scale_y = scale_y
        self.bounds = bounds
        self.fonts_folder = fonts_folder

class PutPresentationMergeRequest(object):

    def __init__(self, name, request = None, password = None, storage = None, folder = None):
        self.name = name
        self.request = request
        self.password = password
        self.storage = storage
        self.folder = folder

class PutSetParagraphPortionPropertiesRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, portion_index, path = None, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.portion_index = portion_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutSetParagraphPropertiesRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutShapeSaveAsRequest(object):

    def __init__(self, name, slide_index, shape_index, format, out_path, path = None, options = None, password = None, folder = None, storage = None, scale_x = None, scale_y = None, bounds = None, fonts_folder = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.format = format
        self.out_path = out_path
        self.path = path
        self.options = options
        self.password = password
        self.folder = folder
        self.storage = storage
        self.scale_x = scale_x
        self.scale_y = scale_y
        self.bounds = bounds
        self.fonts_folder = fonts_folder

class PutSlideAnimationRequest(object):

    def __init__(self, name, slide_index, animation = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.animation = animation
        self.password = password
        self.folder = folder
        self.storage = storage

class PutSlideAnimationEffectRequest(object):

    def __init__(self, name, slide_index, effect_index, effect = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.effect_index = effect_index
        self.effect = effect
        self.password = password
        self.folder = folder
        self.storage = storage

class PutSlideAnimationInteractiveSequenceEffectRequest(object):

    def __init__(self, name, slide_index, sequence_index, effect_index, effect = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.sequence_index = sequence_index
        self.effect_index = effect_index
        self.effect = effect
        self.password = password
        self.folder = folder
        self.storage = storage

class PutSlideSaveAsRequest(object):

    def __init__(self, name, slide_index, format, out_path, options = None, width = None, height = None, password = None, folder = None, storage = None, fonts_folder = None):
        self.name = name
        self.slide_index = slide_index
        self.format = format
        self.out_path = out_path
        self.options = options
        self.width = width
        self.height = height
        self.password = password
        self.folder = folder
        self.storage = storage
        self.fonts_folder = fonts_folder

class PutSlideShapeInfoRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutSlidesConvertRequest(object):

    def __init__(self, format, out_path, document = None, password = None, fonts_folder = None):
        self.format = format
        self.out_path = out_path
        self.document = document
        self.password = password
        self.fonts_folder = fonts_folder

class PutSlidesDocumentFromHtmlRequest(object):

    def __init__(self, name, html = None, password = None, storage = None, folder = None):
        self.name = name
        self.html = html
        self.password = password
        self.storage = storage
        self.folder = folder

class PutSlidesSaveAsRequest(object):

    def __init__(self, name, out_path, format, options = None, password = None, storage = None, folder = None, fonts_folder = None):
        self.name = name
        self.out_path = out_path
        self.format = format
        self.options = options
        self.password = password
        self.storage = storage
        self.folder = folder
        self.fonts_folder = fonts_folder

class PutSlidesSetDocumentPropertyRequest(object):

    def __init__(self, name, property_name, _property = None, password = None, folder = None, storage = None):
        self.name = name
        self.property_name = property_name
        self._property = _property
        self.password = password
        self.folder = folder
        self.storage = storage

class PutSlidesSlideRequest(object):

    def __init__(self, name, slide_index, slide_dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.slide_dto = slide_dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutSlidesSlideBackgroundRequest(object):

    def __init__(self, name, slide_index, background = None, folder = None, password = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.background = background
        self.folder = folder
        self.password = password
        self.storage = storage

class PutSlidesSlideBackgroundColorRequest(object):

    def __init__(self, name, slide_index, color, folder = None, password = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.color = color
        self.folder = folder
        self.password = password
        self.storage = storage

class PutSlidesSlideSizeRequest(object):

    def __init__(self, name, password = None, storage = None, folder = None, width = None, height = None, size_type = None, scale_type = None):
        self.name = name
        self.password = password
        self.storage = storage
        self.folder = folder
        self.width = width
        self.height = height
        self.size_type = size_type
        self.scale_type = scale_type

class PutSlidesViewPropertiesRequest(object):

    def __init__(self, name, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutUpdateNotesSlideRequest(object):

    def __init__(self, name, slide_index, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutUpdateNotesSlideShapeRequest(object):

    def __init__(self, name, slide_index, shape_index, path = None, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutUpdateNotesSlideShapeParagraphRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, path = None, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class PutUpdateNotesSlideShapePortionRequest(object):

    def __init__(self, name, slide_index, shape_index, paragraph_index, portion_index, path = None, dto = None, password = None, folder = None, storage = None):
        self.name = name
        self.slide_index = slide_index
        self.shape_index = shape_index
        self.paragraph_index = paragraph_index
        self.portion_index = portion_index
        self.path = path
        self.dto = dto
        self.password = password
        self.folder = folder
        self.storage = storage

class StorageExistsRequest(object):

    def __init__(self, storage_name):
        self.storage_name = storage_name

class UploadFileRequest(object):

    def __init__(self, file, path = None, storage_name = None):
        self.file = file
        self.path = path
        self.storage_name = storage_name




# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.series import Series

class ScatterSeries(Series):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'name': 'str',
        'is_color_varied': 'bool',
        'inverted_solid_fill_color': 'str',
        'smooth': 'bool',
        'plot_on_second_axis': 'bool',
        'order': 'int',
        'number_format_of_y_values': 'str',
        'number_format_of_x_values': 'str',
        'number_format_of_values': 'str',
        'number_format_of_bubble_sizes': 'str',
        'invert_if_negative': 'bool',
        'explosion': 'int',
        'marker': 'SeriesMarker',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat',
        'data_point_type': 'str',
        'data_points': 'list[ScatterChartDataPoint]'
    }

    attribute_map = {
        'type': 'type',
        'name': 'name',
        'is_color_varied': 'isColorVaried',
        'inverted_solid_fill_color': 'invertedSolidFillColor',
        'smooth': 'smooth',
        'plot_on_second_axis': 'plotOnSecondAxis',
        'order': 'order',
        'number_format_of_y_values': 'numberFormatOfYValues',
        'number_format_of_x_values': 'numberFormatOfXValues',
        'number_format_of_values': 'numberFormatOfValues',
        'number_format_of_bubble_sizes': 'numberFormatOfBubbleSizes',
        'invert_if_negative': 'invertIfNegative',
        'explosion': 'explosion',
        'marker': 'marker',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat',
        'data_point_type': 'dataPointType',
        'data_points': 'dataPoints'
    }

    type_determiners = {
    }

    def __init__(self, type=None, name=None, is_color_varied=None, inverted_solid_fill_color=None, smooth=None, plot_on_second_axis=None, order=None, number_format_of_y_values=None, number_format_of_x_values=None, number_format_of_values=None, number_format_of_bubble_sizes=None, invert_if_negative=None, explosion=None, marker=None, fill_format=None, effect_format=None, line_format=None, data_point_type=None, data_points=None):  # noqa: E501
        """ScatterSeries - a model defined in Swagger"""  # noqa: E501
        super(ScatterSeries, self).__init__(type, name, is_color_varied, inverted_solid_fill_color, smooth, plot_on_second_axis, order, number_format_of_y_values, number_format_of_x_values, number_format_of_values, number_format_of_bubble_sizes, invert_if_negative, explosion, marker, fill_format, effect_format, line_format)

        self._data_point_type = None
        self._data_points = None

        self.data_point_type = data_point_type
        if data_points is not None:
            self.data_points = data_points

    @property
    def data_point_type(self):
        """Gets the data_point_type of this ScatterSeries.  # noqa: E501

        Data point type.  # noqa: E501

        :return: The data_point_type of this ScatterSeries.  # noqa: E501
        :rtype: str
        """
        return self._data_point_type

    @data_point_type.setter
    def data_point_type(self, data_point_type):
        """Sets the data_point_type of this ScatterSeries.

        Data point type.  # noqa: E501

        :param data_point_type: The data_point_type of this ScatterSeries.  # noqa: E501
        :type: str
        """
        if data_point_type is not None:
            allowed_values = ["OneValue", "Scatter", "Bubble"]  # noqa: E501
            if data_point_type.isdigit():
                int_data_point_type = int(data_point_type)
                if int_data_point_type < 0 or int_data_point_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `data_point_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(data_point_type, allowed_values)
                    )
                self._data_point_type = allowed_values[int_data_point_type]
                return
            if data_point_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `data_point_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(data_point_type, allowed_values)
                )
        self._data_point_type = data_point_type

    @property
    def data_points(self):
        """Gets the data_points of this ScatterSeries.  # noqa: E501

        Gets or sets the values.  # noqa: E501

        :return: The data_points of this ScatterSeries.  # noqa: E501
        :rtype: list[ScatterChartDataPoint]
        """
        return self._data_points

    @data_points.setter
    def data_points(self, data_points):
        """Sets the data_points of this ScatterSeries.

        Gets or sets the values.  # noqa: E501

        :param data_points: The data_points of this ScatterSeries.  # noqa: E501
        :type: list[ScatterChartDataPoint]
        """
        self._data_points = data_points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScatterSeries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class ChartCategory(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'categories': 'list[ChartCategory]',
        'value': 'str',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat'
    }

    attribute_map = {
        'categories': 'categories',
        'value': 'value',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat'
    }

    type_determiners = {
    }

    def __init__(self, categories=None, value=None, fill_format=None, effect_format=None, line_format=None):  # noqa: E501
        """ChartCategory - a model defined in Swagger"""  # noqa: E501

        self._categories = None
        self._value = None
        self._fill_format = None
        self._effect_format = None
        self._line_format = None

        if categories is not None:
            self.categories = categories
        if value is not None:
            self.value = value
        if fill_format is not None:
            self.fill_format = fill_format
        if effect_format is not None:
            self.effect_format = effect_format
        if line_format is not None:
            self.line_format = line_format

    @property
    def categories(self):
        """Gets the categories of this ChartCategory.  # noqa: E501

        Gets or sets the categories for chart data  # noqa: E501

        :return: The categories of this ChartCategory.  # noqa: E501
        :rtype: list[ChartCategory]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ChartCategory.

        Gets or sets the categories for chart data  # noqa: E501

        :param categories: The categories of this ChartCategory.  # noqa: E501
        :type: list[ChartCategory]
        """
        self._categories = categories

    @property
    def value(self):
        """Gets the value of this ChartCategory.  # noqa: E501

        Category value  # noqa: E501

        :return: The value of this ChartCategory.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ChartCategory.

        Category value  # noqa: E501

        :param value: The value of this ChartCategory.  # noqa: E501
        :type: str
        """
        self._value = value

    @property
    def fill_format(self):
        """Gets the fill_format of this ChartCategory.  # noqa: E501

        Get or sets the fill format.  # noqa: E501

        :return: The fill_format of this ChartCategory.  # noqa: E501
        :rtype: FillFormat
        """
        return self._fill_format

    @fill_format.setter
    def fill_format(self, fill_format):
        """Sets the fill_format of this ChartCategory.

        Get or sets the fill format.  # noqa: E501

        :param fill_format: The fill_format of this ChartCategory.  # noqa: E501
        :type: FillFormat
        """
        self._fill_format = fill_format

    @property
    def effect_format(self):
        """Gets the effect_format of this ChartCategory.  # noqa: E501

        Get or sets the effect format.  # noqa: E501

        :return: The effect_format of this ChartCategory.  # noqa: E501
        :rtype: EffectFormat
        """
        return self._effect_format

    @effect_format.setter
    def effect_format(self, effect_format):
        """Sets the effect_format of this ChartCategory.

        Get or sets the effect format.  # noqa: E501

        :param effect_format: The effect_format of this ChartCategory.  # noqa: E501
        :type: EffectFormat
        """
        self._effect_format = effect_format

    @property
    def line_format(self):
        """Gets the line_format of this ChartCategory.  # noqa: E501

        Get or sets the line format.  # noqa: E501

        :return: The line_format of this ChartCategory.  # noqa: E501
        :rtype: LineFormat
        """
        return self._line_format

    @line_format.setter
    def line_format(self, line_format):
        """Sets the line_format of this ChartCategory.

        Get or sets the line format.  # noqa: E501

        :param line_format: The line_format of this ChartCategory.  # noqa: E501
        :type: LineFormat
        """
        self._line_format = line_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChartCategory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.export_options import ExportOptions

class ImageExportOptions(ExportOptions):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format': 'str',
        'notes_position': 'str',
        'comments_position': 'str',
        'comments_area_width': 'int',
        'comments_area_color': 'str'
    }

    attribute_map = {
        'format': 'format',
        'notes_position': 'notesPosition',
        'comments_position': 'commentsPosition',
        'comments_area_width': 'commentsAreaWidth',
        'comments_area_color': 'commentsAreaColor'
    }

    type_determiners = {
        'format': 'image',
    }

    def __init__(self, format='image', notes_position=None, comments_position=None, comments_area_width=None, comments_area_color=None):  # noqa: E501
        """ImageExportOptions - a model defined in Swagger"""  # noqa: E501
        super(ImageExportOptions, self).__init__(format)

        self._notes_position = None
        self._comments_position = None
        self._comments_area_width = None
        self._comments_area_color = None
        self.format: 'image'

        self.notes_position = notes_position
        self.comments_position = comments_position
        self.comments_area_width = comments_area_width
        if comments_area_color is not None:
            self.comments_area_color = comments_area_color

    @property
    def notes_position(self):
        """Gets the notes_position of this ImageExportOptions.  # noqa: E501

        Gets or sets the position of the notes on the page.  # noqa: E501

        :return: The notes_position of this ImageExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._notes_position

    @notes_position.setter
    def notes_position(self, notes_position):
        """Sets the notes_position of this ImageExportOptions.

        Gets or sets the position of the notes on the page.  # noqa: E501

        :param notes_position: The notes_position of this ImageExportOptions.  # noqa: E501
        :type: str
        """
        if notes_position is not None:
            allowed_values = ["None", "BottomFull", "BottomTruncated"]  # noqa: E501
            if notes_position.isdigit():
                int_notes_position = int(notes_position)
                if int_notes_position < 0 or int_notes_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(notes_position, allowed_values)
                    )
                self._notes_position = allowed_values[int_notes_position]
                return
            if notes_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `notes_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(notes_position, allowed_values)
                )
        self._notes_position = notes_position

    @property
    def comments_position(self):
        """Gets the comments_position of this ImageExportOptions.  # noqa: E501

        Gets or sets the position of the comments on the page.  # noqa: E501

        :return: The comments_position of this ImageExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_position

    @comments_position.setter
    def comments_position(self, comments_position):
        """Sets the comments_position of this ImageExportOptions.

        Gets or sets the position of the comments on the page.  # noqa: E501

        :param comments_position: The comments_position of this ImageExportOptions.  # noqa: E501
        :type: str
        """
        if comments_position is not None:
            allowed_values = ["None", "Bottom", "Right"]  # noqa: E501
            if comments_position.isdigit():
                int_comments_position = int(comments_position)
                if int_comments_position < 0 or int_comments_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                        .format(comments_position, allowed_values)
                    )
                self._comments_position = allowed_values[int_comments_position]
                return
            if comments_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `comments_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(comments_position, allowed_values)
                )
        self._comments_position = comments_position

    @property
    def comments_area_width(self):
        """Gets the comments_area_width of this ImageExportOptions.  # noqa: E501

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_width of this ImageExportOptions.  # noqa: E501
        :rtype: int
        """
        return self._comments_area_width

    @comments_area_width.setter
    def comments_area_width(self, comments_area_width):
        """Sets the comments_area_width of this ImageExportOptions.

        Gets or sets the width of the comment output area in pixels (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_width: The comments_area_width of this ImageExportOptions.  # noqa: E501
        :type: int
        """
        self._comments_area_width = comments_area_width

    @property
    def comments_area_color(self):
        """Gets the comments_area_color of this ImageExportOptions.  # noqa: E501

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :return: The comments_area_color of this ImageExportOptions.  # noqa: E501
        :rtype: str
        """
        return self._comments_area_color

    @comments_area_color.setter
    def comments_area_color(self, comments_area_color):
        """Sets the comments_area_color of this ImageExportOptions.

        Gets or sets the color of comments area (Applies only if comments are displayed on the right).  # noqa: E501

        :param comments_area_color: The comments_area_color of this ImageExportOptions.  # noqa: E501
        :type: str
        """
        self._comments_area_color = comments_area_color

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageExportOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class PresetShadowEffect(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'direction': 'float',
        'distance': 'float',
        'preset': 'str',
        'shadow_color': 'str'
    }

    attribute_map = {
        'direction': 'direction',
        'distance': 'distance',
        'preset': 'preset',
        'shadow_color': 'shadowColor'
    }

    type_determiners = {
    }

    def __init__(self, direction=None, distance=None, preset=None, shadow_color=None):  # noqa: E501
        """PresetShadowEffect - a model defined in Swagger"""  # noqa: E501

        self._direction = None
        self._distance = None
        self._preset = None
        self._shadow_color = None

        self.direction = direction
        self.distance = distance
        self.preset = preset
        if shadow_color is not None:
            self.shadow_color = shadow_color

    @property
    def direction(self):
        """Gets the direction of this PresetShadowEffect.  # noqa: E501

        direction  # noqa: E501

        :return: The direction of this PresetShadowEffect.  # noqa: E501
        :rtype: float
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this PresetShadowEffect.

        direction  # noqa: E501

        :param direction: The direction of this PresetShadowEffect.  # noqa: E501
        :type: float
        """
        self._direction = direction

    @property
    def distance(self):
        """Gets the distance of this PresetShadowEffect.  # noqa: E501

        distance  # noqa: E501

        :return: The distance of this PresetShadowEffect.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this PresetShadowEffect.

        distance  # noqa: E501

        :param distance: The distance of this PresetShadowEffect.  # noqa: E501
        :type: float
        """
        self._distance = distance

    @property
    def preset(self):
        """Gets the preset of this PresetShadowEffect.  # noqa: E501

        preset  # noqa: E501

        :return: The preset of this PresetShadowEffect.  # noqa: E501
        :rtype: str
        """
        return self._preset

    @preset.setter
    def preset(self, preset):
        """Sets the preset of this PresetShadowEffect.

        preset  # noqa: E501

        :param preset: The preset of this PresetShadowEffect.  # noqa: E501
        :type: str
        """
        if preset is not None:
            allowed_values = ["TopLeftDropShadow", "TopLeftLargeDropShadow", "BackLeftLongPerspectiveShadow", "BackRightLongPerspectiveShadow", "TopLeftDoubleDropShadow", "BottomRightSmallDropShadow", "FrontLeftLongPerspectiveShadow", "FrontRightLongPerspectiveShadow", "OuterBoxShadow3D", "InnerBoxShadow3D", "BackCenterPerspectiveShadow", "TopRightDropShadow", "FrontBottomShadow", "BackLeftPerspectiveShadow", "BackRightPerspectiveShadow", "BottomLeftDropShadow", "BottomRightDropShadow", "FrontLeftPerspectiveShadow", "FrontRightPerspectiveShadow", "TopLeftSmallDropShadow"]  # noqa: E501
            if preset.isdigit():
                int_preset = int(preset)
                if int_preset < 0 or int_preset >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `preset` ({0}), must be one of {1}"  # noqa: E501
                        .format(preset, allowed_values)
                    )
                self._preset = allowed_values[int_preset]
                return
            if preset not in allowed_values:
                raise ValueError(
                    "Invalid value for `preset` ({0}), must be one of {1}"  # noqa: E501
                    .format(preset, allowed_values)
                )
        self._preset = preset

    @property
    def shadow_color(self):
        """Gets the shadow_color of this PresetShadowEffect.  # noqa: E501

        shadow color  # noqa: E501

        :return: The shadow_color of this PresetShadowEffect.  # noqa: E501
        :rtype: str
        """
        return self._shadow_color

    @shadow_color.setter
    def shadow_color(self, shadow_color):
        """Sets the shadow_color of this PresetShadowEffect.

        shadow color  # noqa: E501

        :param shadow_color: The shadow_color of this PresetShadowEffect.  # noqa: E501
        :type: str
        """
        self._shadow_color = shadow_color

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PresetShadowEffect):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.geometry_shape import GeometryShape

class VideoFrame(GeometryShape):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'name': 'str',
        'width': 'float',
        'height': 'float',
        'alternative_text': 'str',
        'alternative_text_title': 'str',
        'hidden': 'bool',
        'x': 'float',
        'y': 'float',
        'z_order_position': 'int',
        'shapes': 'ResourceUriElement',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat',
        'type': 'str',
        'shape_type': 'str',
        'geometry_shape_type': 'str',
        'full_screen_mode': 'bool',
        'hide_at_showing': 'bool',
        'play_loop_mode': 'bool',
        'play_mode': 'str',
        'rewind_video': 'bool',
        'volume': 'str',
        'base64_data': 'str'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'name': 'name',
        'width': 'width',
        'height': 'height',
        'alternative_text': 'alternativeText',
        'alternative_text_title': 'alternativeTextTitle',
        'hidden': 'hidden',
        'x': 'x',
        'y': 'y',
        'z_order_position': 'zOrderPosition',
        'shapes': 'shapes',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat',
        'type': 'type',
        'shape_type': 'shapeType',
        'geometry_shape_type': 'geometryShapeType',
        'full_screen_mode': 'fullScreenMode',
        'hide_at_showing': 'hideAtShowing',
        'play_loop_mode': 'playLoopMode',
        'play_mode': 'playMode',
        'rewind_video': 'rewindVideo',
        'volume': 'volume',
        'base64_data': 'base64Data'
    }

    type_determiners = {
        'type': 'VideoFrame',
        'shapeType': 'VideoFrame',
    }

    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='VideoFrame', shape_type='VideoFrame', geometry_shape_type=None, full_screen_mode=None, hide_at_showing=None, play_loop_mode=None, play_mode=None, rewind_video=None, volume=None, base64_data=None):  # noqa: E501
        """VideoFrame - a model defined in Swagger"""  # noqa: E501
        super(VideoFrame, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type, geometry_shape_type)

        self._full_screen_mode = None
        self._hide_at_showing = None
        self._play_loop_mode = None
        self._play_mode = None
        self._rewind_video = None
        self._volume = None
        self._base64_data = None
        self.type: 'VideoFrame'
        self.shape_type: 'VideoFrame'

        if full_screen_mode is not None:
            self.full_screen_mode = full_screen_mode
        if hide_at_showing is not None:
            self.hide_at_showing = hide_at_showing
        if play_loop_mode is not None:
            self.play_loop_mode = play_loop_mode
        if play_mode is not None:
            self.play_mode = play_mode
        if rewind_video is not None:
            self.rewind_video = rewind_video
        if volume is not None:
            self.volume = volume
        if base64_data is not None:
            self.base64_data = base64_data

    @property
    def full_screen_mode(self):
        """Gets the full_screen_mode of this VideoFrame.  # noqa: E501

        Determines whether a video is shown in full screen mode.  # noqa: E501

        :return: The full_screen_mode of this VideoFrame.  # noqa: E501
        :rtype: bool
        """
        return self._full_screen_mode

    @full_screen_mode.setter
    def full_screen_mode(self, full_screen_mode):
        """Sets the full_screen_mode of this VideoFrame.

        Determines whether a video is shown in full screen mode.  # noqa: E501

        :param full_screen_mode: The full_screen_mode of this VideoFrame.  # noqa: E501
        :type: bool
        """
        self._full_screen_mode = full_screen_mode

    @property
    def hide_at_showing(self):
        """Gets the hide_at_showing of this VideoFrame.  # noqa: E501

        Determines whether a VideoFrame is hidden.   # noqa: E501

        :return: The hide_at_showing of this VideoFrame.  # noqa: E501
        :rtype: bool
        """
        return self._hide_at_showing

    @hide_at_showing.setter
    def hide_at_showing(self, hide_at_showing):
        """Sets the hide_at_showing of this VideoFrame.

        Determines whether a VideoFrame is hidden.   # noqa: E501

        :param hide_at_showing: The hide_at_showing of this VideoFrame.  # noqa: E501
        :type: bool
        """
        self._hide_at_showing = hide_at_showing

    @property
    def play_loop_mode(self):
        """Gets the play_loop_mode of this VideoFrame.  # noqa: E501

        Determines whether a video is looped.  # noqa: E501

        :return: The play_loop_mode of this VideoFrame.  # noqa: E501
        :rtype: bool
        """
        return self._play_loop_mode

    @play_loop_mode.setter
    def play_loop_mode(self, play_loop_mode):
        """Sets the play_loop_mode of this VideoFrame.

        Determines whether a video is looped.  # noqa: E501

        :param play_loop_mode: The play_loop_mode of this VideoFrame.  # noqa: E501
        :type: bool
        """
        self._play_loop_mode = play_loop_mode

    @property
    def play_mode(self):
        """Gets the play_mode of this VideoFrame.  # noqa: E501

        Returns or sets the video play mode.    # noqa: E501

        :return: The play_mode of this VideoFrame.  # noqa: E501
        :rtype: str
        """
        return self._play_mode

    @play_mode.setter
    def play_mode(self, play_mode):
        """Sets the play_mode of this VideoFrame.

        Returns or sets the video play mode.    # noqa: E501

        :param play_mode: The play_mode of this VideoFrame.  # noqa: E501
        :type: str
        """
        if play_mode is not None:
            allowed_values = ["Auto", "OnClick", "AllSlides", "Mixed"]  # noqa: E501
            if play_mode.isdigit():
                int_play_mode = int(play_mode)
                if int_play_mode < 0 or int_play_mode >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `play_mode` ({0}), must be one of {1}"  # noqa: E501
                        .format(play_mode, allowed_values)
                    )
                self._play_mode = allowed_values[int_play_mode]
                return
            if play_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `play_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(play_mode, allowed_values)
                )
        self._play_mode = play_mode

    @property
    def rewind_video(self):
        """Gets the rewind_video of this VideoFrame.  # noqa: E501

        Determines whether a video is automatically rewinded to start as soon as the movie has finished playing  # noqa: E501

        :return: The rewind_video of this VideoFrame.  # noqa: E501
        :rtype: bool
        """
        return self._rewind_video

    @rewind_video.setter
    def rewind_video(self, rewind_video):
        """Sets the rewind_video of this VideoFrame.

        Determines whether a video is automatically rewinded to start as soon as the movie has finished playing  # noqa: E501

        :param rewind_video: The rewind_video of this VideoFrame.  # noqa: E501
        :type: bool
        """
        self._rewind_video = rewind_video

    @property
    def volume(self):
        """Gets the volume of this VideoFrame.  # noqa: E501

        Returns or sets the audio volume.  # noqa: E501

        :return: The volume of this VideoFrame.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this VideoFrame.

        Returns or sets the audio volume.  # noqa: E501

        :param volume: The volume of this VideoFrame.  # noqa: E501
        :type: str
        """
        if volume is not None:
            allowed_values = ["Mute", "Low", "Medium", "Loud", "Mixed"]  # noqa: E501
            if volume.isdigit():
                int_volume = int(volume)
                if int_volume < 0 or int_volume >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `volume` ({0}), must be one of {1}"  # noqa: E501
                        .format(volume, allowed_values)
                    )
                self._volume = allowed_values[int_volume]
                return
            if volume not in allowed_values:
                raise ValueError(
                    "Invalid value for `volume` ({0}), must be one of {1}"  # noqa: E501
                    .format(volume, allowed_values)
                )
        self._volume = volume

    @property
    def base64_data(self):
        """Gets the base64_data of this VideoFrame.  # noqa: E501

        Video data encoded in base64.  # noqa: E501

        :return: The base64_data of this VideoFrame.  # noqa: E501
        :rtype: str
        """
        return self._base64_data

    @base64_data.setter
    def base64_data(self, base64_data):
        """Sets the base64_data of this VideoFrame.

        Video data encoded in base64.  # noqa: E501

        :param base64_data: The base64_data of this VideoFrame.  # noqa: E501
        :type: str
        """
        self._base64_data = base64_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoFrame):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.shape_base import ShapeBase

class SmartArtShape(ShapeBase):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'self_uri': 'ResourceUri',
        'alternate_links': 'list[ResourceUri]',
        'name': 'str',
        'width': 'float',
        'height': 'float',
        'alternative_text': 'str',
        'alternative_text_title': 'str',
        'hidden': 'bool',
        'x': 'float',
        'y': 'float',
        'z_order_position': 'int',
        'shapes': 'ResourceUriElement',
        'fill_format': 'FillFormat',
        'effect_format': 'EffectFormat',
        'line_format': 'LineFormat',
        'type': 'str',
        'shape_type': 'str'
    }

    attribute_map = {
        'self_uri': 'selfUri',
        'alternate_links': 'alternateLinks',
        'name': 'name',
        'width': 'width',
        'height': 'height',
        'alternative_text': 'alternativeText',
        'alternative_text_title': 'alternativeTextTitle',
        'hidden': 'hidden',
        'x': 'x',
        'y': 'y',
        'z_order_position': 'zOrderPosition',
        'shapes': 'shapes',
        'fill_format': 'fillFormat',
        'effect_format': 'effectFormat',
        'line_format': 'lineFormat',
        'type': 'type',
        'shape_type': 'shapeType'
    }

    type_determiners = {
        'type': 'SmartArtShape',
        'shapeType': 'Custom',
    }

    def __init__(self, self_uri=None, alternate_links=None, name=None, width=None, height=None, alternative_text=None, alternative_text_title=None, hidden=None, x=None, y=None, z_order_position=None, shapes=None, fill_format=None, effect_format=None, line_format=None, type='SmartArtShape', shape_type='Custom'):  # noqa: E501
        """SmartArtShape - a model defined in Swagger"""  # noqa: E501
        super(SmartArtShape, self).__init__(self_uri, alternate_links, name, width, height, alternative_text, alternative_text_title, hidden, x, y, z_order_position, shapes, fill_format, effect_format, line_format, type, shape_type)
        self.type: 'SmartArtShape'
        self.shape_type: 'Custom'

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmartArtShape):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
